==> openkb-1.0.18.tgz: package/locales/de.js <==
{
	"Toggle navigation": "Navigations ändern",
	"Users": "Benutzer",
	"New": "Neu",
	"Edit": "Ändern",
	"My account": "Mein Profil",
	"Article": "Artikel",
	"Settings": "Einstellungen",
	"Files": "Dateien",
	"Export": "Exportieren",
	"Cleanup files": "Dateien aufräumen",
	"Logout": "Abmelden",
	"Powered by": "Powered by",
	"Home": "Home",
	"Articles": "Artikel",
	"Filter articles": "Artikel filtern",
	"Filter": "Filter",
	"Reset": "Zurücksetzen",
	"All": "Alle",
	"Published": "Veröffentlicht",
	"Recent": "Kürzlich",
	"Are you sure you want to delete this article?": "Sind Sie sich sicher, dass Sie den Artikel löschen wollen?",
	"Search": "Suchen",
	"Featured articles": "gefeaturete Artikel",
	"Top articles": "Top-Artikel",
	"Suggest": "Vorschlagen",
	"Login": "Anmelden",
	"Please sign in": "Bitte melden Sie sich an",
	"email address": "Email Adresse",
	"Password": "Passwort",
	"Sign in": "Anmelden",
	"Website": "Website",
	"Display": "Anzeige",
	"Update": "Aktualisieren",
	"Website title": "Websitetitel",
	"The title of your website": "Der Titel der Webseite",
	"Website description": "Beschreibung der Webseite",
	"A short website description when listing the homepage URL in search engines": "Eine kurze Beschreibung die bei Einträgen in Suchmaschinen (z.B. Google) angezeigt wird",
	"Show website logo": "Zeige das Webseite-Logo",
	"true": "Wahr",
	"false": "falsch",
	"Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)": "Steuert ob der Text 'Website title' oder das Logo (Standard) von '/public/logo.png' angezeigt wird",
	"Website context/base URL": "Website context/base URL (meist Domain-Name)",
	"Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/": "Erlaubt der Applikation aus einem nicht-administrativen Pfad aus zu starten. z.B.: http://127.0.0.1:4444/openkb/",
	"Allow API access": "Erlaube zugriff auf die API",
	"Whether to allow API access to insert articles - See documentation for further information": "Erlaubt das Hinzufügen von Artikeln über die API - Weiterführende Informationen in der Dokumentation",
	"API access token": "API Zugriffstoken",
	"Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value": "Benötigt 'Allow API access' gleich 'wahr'. Der Wert ist das das Zugriffstoken das notwendig ist um Änderungen über die API zu machen. Bitte auf einen komplizierten wert setzen",
	"Password protect": "Mit Passwort sichern",
	"Setting to 'true' will require a user to login before viewing any pages": "Nur angemeldete Benutzer können Artikel sehen, wenn der Wert auf 'true' gesetzt ist",
	"Index article body": "Indiziere den Inhalt des Artikels für eine schnellere Suche",
	"Whether to add the body of your articles to the search index (requires restart)": "Soll der Inhalt der Artikel dem Suchindex hinzugefügt werden? (Benötigt einen Neustart der Applikation)",
	"Select a theme": "Wählen Sie ein Anwendungsstil",
	"The theme to use for public facing pages. Leave blank for default": "Der Stil, der für öffentliche Seiten verwendet werden soll. Wenn keines ausgewählt ist wird der Standardstil verwendet",
	"Show logon link": "Zeige den Link zur Anmeldung",
	"Whether to show/hide the logon link in the top right of screen": "Zeigt oder Versteckt den Link zur Anmeldung in der oberen rechten Ecke",
	"Date format": "Datumsformat",
	"Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying": "Setzt das globale Datumsformat mit Hilfe von 'moment.js'. (Weitere Informationen http://momentjs.com/docs/#/displaying)",
	"Article suggestions allowed": "Erlaube Artikel vorzuschlagen",
	"If enabled non authenticated users can submit article suggestions for approval": "Wenn aktiviert, ist es nicht registrierten Benutzern mögliche Artikel vorzuschlagen, die dann bestätigt werden müssen.",
	"Google analytics code": "Google analytics Code",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags",
	"Allow voting": "Erlaube Bewertung",
	"Whether to allow users to vote on an article": "Ist es Benutzern möglich Artikel zu Bewerten",
	"Show article meta data": "Zeige Metadaten eines Artikels",
	"Whether to show article meta data including published date, last updated date, author etc": "Sollen Metadaten eines Artikels, wie Veröffentlichungsdatum, Aktualisierungsdatum, Autor etc., angezeigt werden",
	"Show author email": "Show author email",
	"Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true": "Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true",
	"Article links open new page": "Article links open new page",
	"Controls whether links within articles open a new page (tab)": "Controls whether links within articles open a new page (tab)",
	"Add header anchors": "Add header anchors",
	"Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles": "Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles",
	"Enable editor spellchecker": "Enable editor spellchecker",
	"Controls whether to enable the editor spellchecker": "Controls whether to enable the editor spellchecker",
	"Allow article versioning": "Allow article versioning",
	"Whether to track article versions with each save of the editor": "Whether to track article versions with each save of the editor",
	"Number of top articles shown on homepage": "Number of top articles shown on homepage",
	"Sets the number of results shown on the home page": "Sets the number of results shown on the home page",
	"Show published date": "Show published date",
	"Shows the published date next to the results on the homepage and search": "Shows the published date next to the results on the homepage and search",
	"Show view count": "Show view count",
	"Shows the view count next to the results on the homepage and search": "Shows the view count next to the results on the homepage and search",
	"Update view count when logged in": "Update view count when logged in",
	"Updates the view count also when users are logged in": "Updates the view count also when users are logged in",
	"Show featured articles": "Show featured articles",
	"Whether to show any articles set to featured in a sidebar": "Whether to show any articles set to featured in a sidebar",
	"Show featured articles when viewing article": "Show featured articles when viewing article",
	"Whether to show any articles set to featured in a sidebar when viewing an article": "Sollen gefeaturete Artikel bei der Ansicht eines Artikels in einer Seitenleiste angezeigt werden",
	"Featured article count": "Anzahl der gefeatureten Artikel",
	"The number of featured articles shown": "Die Anzahl der sichtbaren Feature-Artikel",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags": "Fügt Google Analyticszu öffentlichen Seiten hinzu. Fügen Sie den kompletten Quellcode von Google ein (inkl. <script>-Tag)",
	"New user": "Neuer Benutzer",
	"Users name": "Benutzername",
	"User email": "Benutzer-Email",
	"User password": "Benutzer-Passwort",
	"Password confirm": "Passwort bestätigen",
	"Create": "Erstellen",
	"A user with that email address already exists": "Ein Benutzer mit dieser Email-Adresse existiert bereits",
	"User": "Benutzer",
	"Role": "Rolle",
	"Admin": "Administrator",
	"Are you sure you want to delete?": "Sind Sie sicher, dass sie das löschen wollen?",
	"User edit": "Benutzer editieren",
	"Password values do not match": "Die Passwörter stimmen nicht überein",
	"Date": "Datum",
	"View count": "Ansichten",
	"Controls whether to show the \"Website title\" text or a logo located: \"/public/logo.png\" (by default)": "Steuert ob der Text 'Website title' oder das Logo (Standard) von '/public/logo.png' angezeigt wird",
	"Requires \"Allow API access\" to be set to \"true\". The value is the access token required to access the public API. Please set to a hard to guess value": "Benötigt \"Erlaube zugriff auf die API\". Der Wert ist das das Zugriffstoken das notwendig ist um Änderungen über die API zu machen. Bitte auf einen komplizierten wert setzen",
	"Setting to \"true\" will require a user to login before viewing any pages": "Ein Benutzer muss angemeldet sein bevor er Seiten sehen/lesen kann.",
	"Controls whether the authors email address is displayed in the meta. Requires \"Show article meta data\" to be true": "Steuert ob die Email des Autors in den Metadaten des Artikels angezeigt wird oder nicht. (Benötigt \"Zeige Artikel-Metadaten\")",
	"Article title": "Titel",
	"Status": "Status",
	"Draft": "Entwurf",
	"Insert": "Einfügen",
	"Article body": "Artikelinhalt",
	"Preview": "Vorschau",
	"comma, separated, list": "Durch Komma separierte Liste",
	"Permalink for the article": "Permalink für den Artikel",
	"Validate": "Überprüfen",
	"Generate": "Generieren",
	"Select file": "Datei auswählen",
	"Upload directory": "Verzeichnis hochladen",
	"Upload file": "Datei hochladen",
	"Tip": "Tipp",
	"To insert an image right click the link, copy the link address and add it to your Markdown": "Um ein Bild hinzuzufügen kann die Bild-URL in den Markdown bereich eingefügt werden",
	"New directory": "Neues Verzeichnis",
	"Multiple directories can be created using a \"/\" separator": "Mehrere Verzeichnisse können erstellt werden, indem sie durch einen \"/\" getrennt sind",
	"All unused files have been removed": "Alle nicht mehr benötigten Datein wurden entfernt",
	"New article successfully created": "Der neue Artikel wurde erfolgreich erstellt",
	"keyword": "Schlüsselwort",
	"permalink": "Permanenter Link",
	"Delete": "Löschen",
	"Reset views": "Ansichten zurücksetzen",
	"Reset votes": "Bewertungen zurücksetzen",
	"Featured article": "Gefeatureter Artikel",
	"SEO title": "SEO-Titel",
	"SEO description": "SEO-Beschreibung",
	"Successfully saved": "Erfolgreich gespeichert",
	"Filtered term": "Filter",
	"Settings successfully updated.": "Die Einstellungen wurden erfolgreich aktualisiert",
	"Setup": "Setup",
	"Email address": "Email-Adresse",
	"Confirm password": "Passwort bestätigen",
	"Complete setup": "Setup vervollständigen",
	"User account inserted": "Das Benutzerkonto wurde erstellt",
	"Search the knowledge base": "Durchsuchen...",
	"Was this article helpful?": "War dieser Artikel hilfreich?",
	"Votes": "Bewertungen",
	"Article details": "Artikeldetails",
	"Published date": "Veröffentlichungsdatum",
	"Last updated": "Zuletzt aktualisiert",
	"Share article": "Artikel teilen",
	"Author": "Autor",
	"Keywords": "Keywords"
}

==> openkb-1.0.19.tgz: package/locales/de.js <==
{
	"Toggle navigation": "Navigations ändern",
	"Users": "Benutzer",
	"New": "Neu",
	"Edit": "Ändern",
	"My account": "Mein Profil",
	"Article": "Artikel",
	"Settings": "Einstellungen",
	"Files": "Dateien",
	"Export": "Exportieren",
	"Cleanup files": "Dateien aufräumen",
	"Logout": "Abmelden",
	"Powered by": "Powered by",
	"Home": "Home",
	"Articles": "Artikel",
	"Filter articles": "Artikel filtern",
	"Filter": "Filter",
	"Reset": "Zurücksetzen",
	"All": "Alle",
	"Published": "Veröffentlicht",
	"Recent": "Kürzlich",
	"Are you sure you want to delete this article?": "Sind Sie sich sicher, dass Sie den Artikel löschen wollen?",
	"Search": "Suchen",
	"Featured articles": "gefeaturete Artikel",
	"Top articles": "Top-Artikel",
	"Suggest": "Vorschlagen",
	"Login": "Anmelden",
	"Please sign in": "Bitte melden Sie sich an",
	"email address": "Email Adresse",
	"Password": "Passwort",
	"Sign in": "Anmelden",
	"Website": "Website",
	"Display": "Anzeige",
	"Update": "Aktualisieren",
	"Website title": "Websitetitel",
	"The title of your website": "Der Titel der Webseite",
	"Website description": "Beschreibung der Webseite",
	"A short website description when listing the homepage URL in search engines": "Eine kurze Beschreibung die bei Einträgen in Suchmaschinen (z.B. Google) angezeigt wird",
	"Show website logo": "Zeige das Webseite-Logo",
	"true": "Wahr",
	"false": "falsch",
	"Controls whether to show the 'Website title' text or a logo located: '/public/logo.png' (by default)": "Steuert ob der Text 'Website title' oder das Logo (Standard) von '/public/logo.png' angezeigt wird",
	"Website context/base URL": "Website context/base URL (meist Domain-Name)",
	"Allows for the website to be run from a non root path. Eg: http://127.0.0.1:4444/openkb/": "Erlaubt der Applikation aus einem nicht-administrativen Pfad aus zu starten. z.B.: http://127.0.0.1:4444/openkb/",
	"Allow API access": "Erlaube zugriff auf die API",
	"Whether to allow API access to insert articles - See documentation for further information": "Erlaubt das Hinzufügen von Artikeln über die API - Weiterführende Informationen in der Dokumentation",
	"API access token": "API Zugriffstoken",
	"Requires 'Allow API access' to be set to 'true'. The value is the access token required to access the public API. Please set to a hard to guess value": "Benötigt 'Allow API access' gleich 'wahr'. Der Wert ist das das Zugriffstoken das notwendig ist um Änderungen über die API zu machen. Bitte auf einen komplizierten wert setzen",
	"Password protect": "Mit Passwort sichern",
	"Setting to 'true' will require a user to login before viewing any pages": "Nur angemeldete Benutzer können Artikel sehen, wenn der Wert auf 'true' gesetzt ist",
	"Index article body": "Indiziere den Inhalt des Artikels für eine schnellere Suche",
	"Whether to add the body of your articles to the search index (requires restart)": "Soll der Inhalt der Artikel dem Suchindex hinzugefügt werden? (Benötigt einen Neustart der Applikation)",
	"Select a theme": "Wählen Sie ein Anwendungsstil",
	"The theme to use for public facing pages. Leave blank for default": "Der Stil, der für öffentliche Seiten verwendet werden soll. Wenn keines ausgewählt ist wird der Standardstil verwendet",
	"Show logon link": "Zeige den Link zur Anmeldung",
	"Whether to show/hide the logon link in the top right of screen": "Zeigt oder Versteckt den Link zur Anmeldung in der oberen rechten Ecke",
	"Date format": "Datumsformat",
	"Sets the global date formatting. Uses moment.js date formatting, see more here: http://momentjs.com/docs/#/displaying": "Setzt das globale Datumsformat mit Hilfe von 'moment.js'. (Weitere Informationen http://momentjs.com/docs/#/displaying)",
	"Article suggestions allowed": "Erlaube Artikel vorzuschlagen",
	"If enabled non authenticated users can submit article suggestions for approval": "Wenn aktiviert, ist es nicht registrierten Benutzern mögliche Artikel vorzuschlagen, die dann bestätigt werden müssen.",
	"Google analytics code": "Google analytics Code",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags": "Adds Google Analytics to public facing pages. Include the entire code from Google including the &lt;script&gt; tags",
	"Allow voting": "Erlaube Bewertung",
	"Whether to allow users to vote on an article": "Ist es Benutzern möglich Artikel zu Bewerten",
	"Show article meta data": "Zeige Metadaten eines Artikels",
	"Whether to show article meta data including published date, last updated date, author etc": "Sollen Metadaten eines Artikels, wie Veröffentlichungsdatum, Aktualisierungsdatum, Autor etc., angezeigt werden",
	"Show author email": "Show author email",
	"Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true": "Controls whether the authors email address is displayed in the meta. Requires 'Show article meta data' to be true",
	"Article links open new page": "Article links open new page",
	"Controls whether links within articles open a new page (tab)": "Controls whether links within articles open a new page (tab)",
	"Add header anchors": "Add header anchors",
	"Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles": "Whether to add HTML anchors to all heading tags for linking within articles or direct linking from other articles",
	"Enable editor spellchecker": "Enable editor spellchecker",
	"Controls whether to enable the editor spellchecker": "Controls whether to enable the editor spellchecker",
	"Allow article versioning": "Allow article versioning",
	"Whether to track article versions with each save of the editor": "Whether to track article versions with each save of the editor",
	"Number of top articles shown on homepage": "Number of top articles shown on homepage",
	"Sets the number of results shown on the home page": "Sets the number of results shown on the home page",
	"Show published date": "Show published date",
	"Shows the published date next to the results on the homepage and search": "Shows the published date next to the results on the homepage and search",
	"Show view count": "Show view count",
	"Shows the view count next to the results on the homepage and search": "Shows the view count next to the results on the homepage and search",
	"Update view count when logged in": "Update view count when logged in",
	"Updates the view count also when users are logged in": "Updates the view count also when users are logged in",
	"Show featured articles": "Show featured articles",
	"Whether to show any articles set to featured in a sidebar": "Whether to show any articles set to featured in a sidebar",
	"Show featured articles when viewing article": "Show featured articles when viewing article",
	"Whether to show any articles set to featured in a sidebar when viewing an article": "Sollen gefeaturete Artikel bei der Ansicht eines Artikels in einer Seitenleiste angezeigt werden",
	"Featured article count": "Anzahl der gefeatureten Artikel",
	"The number of featured articles shown": "Die Anzahl der sichtbaren Feature-Artikel",
	"Adds Google Analytics to public facing pages. Include the entire code from Google including the <script> tags": "Fügt Google Analyticszu öffentlichen Seiten hinzu. Fügen Sie den kompletten Quellcode von Google ein (inkl. <script>-Tag)",
	"New user": "Neuer Benutzer",
	"Users name": "Benutzername",
	"User email": "Benutzer-Email",
	"User password": "Benutzer-Passwort",
	"Password confirm": "Passwort bestätigen",
	"Create": "Erstellen",
	"A user with that email address already exists": "Ein Benutzer mit dieser Email-Adresse existiert bereits",
	"User": "Benutzer",
	"Role": "Rolle",
	"Admin": "Administrator",
	"Are you sure you want to delete?": "Sind Sie sicher, dass sie das löschen wollen?",
	"User edit": "Benutzer editieren",
	"Password values do not match": "Die Passwörter stimmen nicht überein",
	"Date": "Datum",
	"View count": "Ansichten",
	"Controls whether to show the \"Website title\" text or a logo located: \"/public/logo.png\" (by default)": "Steuert ob der Text 'Website title' oder das Logo (Standard) von '/public/logo.png' angezeigt wird",
	"Requires \"Allow API access\" to be set to \"true\". The value is the access token required to access the public API. Please set to a hard to guess value": "Benötigt \"Erlaube zugriff auf die API\". Der Wert ist das das Zugriffstoken das notwendig ist um Änderungen über die API zu machen. Bitte auf einen komplizierten wert setzen",
	"Setting to \"true\" will require a user to login before viewing any pages": "Ein Benutzer muss angemeldet sein bevor er Seiten sehen/lesen kann.",
	"Controls whether the authors email address is displayed in the meta. Requires \"Show article meta data\" to be true": "Steuert ob die Email des Autors in den Metadaten des Artikels angezeigt wird oder nicht. (Benötigt \"Zeige Artikel-Metadaten\")",
	"Article title": "Titel",
	"Status": "Status",
	"Draft": "Entwurf",
	"Insert": "Einfügen",
	"Article body": "Artikelinhalt",
	"Preview": "Vorschau",
	"comma, separated, list": "Durch Komma separierte Liste",
	"Permalink for the article": "Permalink für den Artikel",
	"Validate": "Überprüfen",
	"Generate": "Generieren",
	"Select file": "Datei auswählen",
	"Upload directory": "Verzeichnis hochladen",
	"Upload file": "Datei hochladen",
	"Tip": "Tipp",
	"To insert an image right click the link, copy the link address and add it to your Markdown": "Um ein Bild hinzuzufügen kann die Bild-URL in den Markdown bereich eingefügt werden",
	"New directory": "Neues Verzeichnis",
	"Multiple directories can be created using a \"/\" separator": "Mehrere Verzeichnisse können erstellt werden, indem sie durch einen \"/\" getrennt sind",
	"All unused files have been removed": "Alle nicht mehr benötigten Datein wurden entfernt",
	"New article successfully created": "Der neue Artikel wurde erfolgreich erstellt",
	"keyword": "Schlüsselwort",
	"permalink": "Permanenter Link",
	"Delete": "Löschen",
	"Reset views": "Ansichten zurücksetzen",
	"Reset votes": "Bewertungen zurücksetzen",
	"Featured article": "Gefeatureter Artikel",
	"SEO title": "SEO-Titel",
	"SEO description": "SEO-Beschreibung",
	"Successfully saved": "Erfolgreich gespeichert",
	"Filtered term": "Filter",
	"Settings successfully updated.": "Die Einstellungen wurden erfolgreich aktualisiert",
	"Setup": "Setup",
	"Email address": "Email-Adresse",
	"Confirm password": "Passwort bestätigen",
	"Complete setup": "Setup vervollständigen",
	"User account inserted": "Das Benutzerkonto wurde erstellt",
	"Search the knowledge base": "Durchsuchen...",
	"Was this article helpful?": "War dieser Artikel hilfreich?",
	"Votes": "Bewertungen",
	"Article details": "Artikeldetails",
	"Published date": "Veröffentlichungsdatum",
	"Last updated": "Zuletzt aktualisiert",
	"Share article": "Artikel teilen",
	"Author": "Autor",
	"Keywords": "Keywords",
	"Import": "Import",
	"Select a language": "Select a language",
	"The language to use for public facing pages. Leave blank for default (English)": "The language to use for public facing pages. Leave blank for default (English)"
}
